pub struct CoverageAnalysis {
pub char_coverage_rate: f64,
pub word_coverage_rate: f64,
pub compression_ratio: f64,
pub total_chars: usize,
pub total_words: usize,
pub total_tokens: usize,
pub covered_chars: usize,
pub covered_words: usize,
pub length_distribution: HashMap<usize, u32>,
pub oov_tokens: Vec<String>,
pub vocab_size: usize,
}Expand description
Detailed coverage analysis results for tokenizer evaluation.
Fields
char_coverage_rate: f64Character-level coverage rate (0.0 to 1.0)
word_coverage_rate: f64Word-level coverage rate (0.0 to 1.0)
compression_ratio: f64Compression ratio (tokens per character)
total_chars: usizeTotal characters in the test corpus
total_words: usizeTotal words in the test corpus
total_tokens: usizeTotal tokens produced by tokenization
covered_chars: usizeNumber of characters covered by the vocabulary
covered_words: usizeNumber of words covered by the vocabulary
length_distribution: HashMap<usize, u32>Distribution of token lengths
oov_tokens: Vec<String>List of out-of-vocabulary tokens encountered
vocab_size: usizeSize of the tokenizer vocabulary
Implementations
Sourceimpl CoverageAnalysis
impl CoverageAnalysis
Sourcepub fn summary(&self) -> String
pub fn summary(&self) -> String
Generate a comprehensive summary report of the coverage analysis.
Sourcepub fn average_token_length(&self) -> f64
pub fn average_token_length(&self) -> f64
Calculate average token length based on the length distribution.
Sourcepub fn top_token_lengths(&self, n: usize) -> Vec<(usize, u32)>
pub fn top_token_lengths(&self, n: usize) -> Vec<(usize, u32)>
Get the most common token lengths with their frequencies.
Sourcepub fn efficiency_score(&self) -> f64
pub fn efficiency_score(&self) -> f64
Calculate efficiency score combining coverage and compression.